Stan Math Library: stan::math::index_type< const T > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::index_type< const T > Struct Template Reference

Template class for metaprogram to compute the type of indexes used in a constant container type. More...

`#include <index_type.hpp>`

## Public Types
typedef index_type< T >::type | type

## Detailed Description

### template<typename T>
struct stan::math::index_type< const T >

Template class for metaprogram to compute the type of indexes used in a constant container type.

Template Parameters

  T | type of container without const modifier.

Definition at line 30 of file index_type.hpp.

## Member Typedef Documentation

template<typename T >

typedef index_type<T>::type stan::math::index_type< const T >::type

Definition at line 31 of file index_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/index_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.